/**
 * INIT FUNCTION
 ====================================================== */
(function($) {

    'use strict';

    window.RWApp = {

        // Settings
        $window: $(window),
        $body: $('body'),

        // Initialise the object
        // ---------------------------------------------- /
        init: function() {
            this.bind();
            this.houses();
            this.projects();
        },

        // Global binds
        // ---------------------------------------------- /
        bind: function() {
            var self = this;

            // Read more
            this.readMore('.read-more--active');
        },

        // Read more
        // ---------------------------------------------- /
        readMore: function(el, num = 10) {
            const $readMores = $(el);
            if($readMores.length < 1) return;

            $readMores.each(function( index ) {

                const $readMore = $(this);
                const activeClass = 'read-more--active';
                const $readMoreBtn = $readMore.find('.read-more__btn');

                const readMoreText = $readMoreBtn.text();
                const readLessText = $readMoreBtn.data('text-less');

                $readMoreBtn.on('click', function () {

                    if ($readMore.hasClass(activeClass)) {
                        $readMoreBtn.text(readLessText);
                        $readMore.removeClass(activeClass);
                    } else {
                        $readMore.addClass(activeClass);
                        $readMoreBtn.text(readMoreText);
                    }

                });
            });
        },

        // Houses
        // ---------------------------------------------- /
        houses: function() {
            let openFilterLabel = '';
            const openClass = 'rw-btn-more-filter--open';
            const openBodyClass = 'rw-filter-open';
            $('.rw-btn-more-filter').on( 'click', function() {
                const $btn = $(this);
                if(openFilterLabel === '') {
                    openFilterLabel = $btn.text();
                }
                const closeFilterLabel = $btn.data('close-label');

                if($btn.hasClass(openClass)){
                    $btn.removeClass(openClass);
                    $('body').removeClass(openBodyClass);
                    $btn.text(openFilterLabel);
                } else {
                    $btn.addClass(openClass);
                    $('body').addClass(openBodyClass);
                    $btn.text(closeFilterLabel);
                }

                $('.rw-search-form').toggleClass( 'rw-search-form--more-filter-open' );
            });

            $('.rw-search-form-collapse-trigger').on( 'click', function() {
                $(this).toggleClass( 'rw-search-form-collapse-trigger--open' );
                $('.rw-search-form').toggleClass( 'rw-search-form--open' );
            });

            $('.bouwtype-modal-open').on( 'click', function() {
                const id = $(this).data('bouwtype-modal-id');
                $('#bouwtype-modal-'+id).addClass( 'bouwtype-modal--active' );
            });
        },

        // Projects
        // ---------------------------------------------- /
        projects: function() {
            $('.bouwtype-modal-open').on( 'click', function() {
                const id = $(this).data('bouwtype-modal-id');
                $('#bouwtype-modal-'+id).addClass( 'bouwtype-modal--active' );
            });

            $('.bouwtype-modal-close').on( 'click', function() {
                $('.bouwtype-modal').removeClass( 'bouwtype-modal--active' );
            });

        },
    };

})(jQuery);